@@ -1,6 +1,7 @@
 package Shell::Amazon::S3::CommandDispatcher;
 use Moose;
-use Module::Find;
+use Module::Pluggable::Object;
+use Class::MOP;
 use Shell::Amazon::S3::Utils;
 
 has 'dispatch_table' => (
@@ -8,8 +9,10 @@ has 'dispatch_table' => (
     isa      => 'HashRef',
     required => 1,
     default  => sub {
-        my @commands = usesub Shell::Amazon::S3::Command;
-        #require $_ for @commands;
+        my $finder = Module::Pluggable::Object->new(
+            search_path => 'Shell::Amazon::S3::Command', );
+        my @commands = $finder->plugins;
+        Class::MOP::load_class($_) for @commands;
         my %table
             = map { Shell::Amazon::S3::Utils->classsuffix($_) => $_->new }
             @commands;
